﻿using System;
using System.Windows.Forms;
using System.IO;

namespace CopiarArquivosBinarios
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void btnCopiar_Click(object sender, EventArgs e)
        {
            if (rdbBinario.Checked)
            {
               if(validarArquivos())
                CopiarArquivoBinario(@txtOrigem.Text, @txtDestino.Text);
               else
                     MessageBox.Show("Não foi possível encontrar o arquivo Origem","Erro",MessageBoxButtons.OK,MessageBoxIcon.Information);
            }
            else if (rdbTexto.Checked)
            {
                if (validarArquivos())
                    CopiarArquivoTexto(txtOrigem.Text, txtDestino.Text);
                else
                    MessageBox.Show("Não foi possível encontrar o arquivo Origem", "Erro", MessageBoxButtons.OK, MessageBoxIcon.Information);
            }
            else
            {
                MessageBox.Show("Selecione o tipo de arquivo a ser copiado", "Erro", MessageBoxButtons.OK, MessageBoxIcon.Information);
            }
        }

        static bool CopiarArquivoBinario(string nomeArquivoOrigem, string nomeArquivoDestino)
        {
            if (File.Exists(nomeArquivoOrigem) == false)
            {
                MessageBox.Show("Não foi possível encontrar o arquivo Origem","Erro",MessageBoxButtons.OK,MessageBoxIcon.Information);
                return false;
            }
            if (File.Exists(nomeArquivoDestino) == true)
            {
                if(MessageBox.Show("Já existe um arquivo com esse nome na pasta indicada, deseja sobrepor este arquivo?", "Sobrepor", MessageBoxButtons.YesNo)==DialogResult.No)
                   return false;
            }
            try
            {
                Stream s1 = File.Open(@nomeArquivoOrigem, FileMode.Open);
                Stream s2 =  File.Open(@nomeArquivoDestino, FileMode.Create);

                BinaryReader f1 = new BinaryReader(s1);
                BinaryWriter f2 = new BinaryWriter(s2);

                while (true)
                {
                    byte[] buf = new byte[10240];
                    int sz = f1.Read(buf, 0, 10240);
                    if (sz <= 0)
                        break;
                    f2.Write(buf, 0, sz);
                    if (sz < 10240)
                        break; // eof reached
                }
                f1.Close();
                f2.Close();
                MessageBox.Show("Arquivo " + nomeArquivoOrigem +  " copiado com sucesso. ", "Sucesso", MessageBoxButtons.OK, MessageBoxIcon.Information);
                return true;
            }
            catch (Exception ex)
            {
                MessageBox.Show("Erro ao copiar a o arquivo ...: " + ex.Message, "Erro", MessageBoxButtons.OK, MessageBoxIcon.Information);
                return false;
            }
        }
        /// <summary>
        /// 
        /// </summary>
        /// <param name="nomeArquivoOrigem"></param>
        /// <param name="nomeArquivoDestino"></param>
        /// <returns></returns>
        static bool CopiarArquivoTexto(string nomeArquivoOrigem, string nomeArquivoDestino)
        {
            if (File.Exists(nomeArquivoOrigem) == false)
            {
                MessageBox.Show("Não foi possível encontrar o arquivo Origem", "Erro", MessageBoxButtons.OK, MessageBoxIcon.Information);
                return false;
            }

            if (File.Exists(nomeArquivoDestino) == true)
            {
                MessageBox.Show("Já existe um arquivo com esse nome na pasta indicada, deseja sobrepor este arquivo?", "Sobepor", MessageBoxButtons.YesNo, MessageBoxIcon.Information);
                return false;
            }
         try
         {
           StreamReader f1 = new StreamReader(nomeArquivoOrigem);
           StreamWriter f2 = new StreamWriter(nomeArquivoDestino);

            while (true)
            {
                char[] buf = new char[1024];
                int sz = f1.Read(buf, 0, 1024);
                if (sz <= 0)
                    break;
                f2.Write(buf, 0, sz);
                if (sz < 1024)
                    break; // eof reached
            }
            f1.Close();
            f2.Close();
            return true;
         }
         catch (Exception ex)
         {
             MessageBox.Show("Erro ao copiar a o arquivo ...: " + ex.Message, "Erro", MessageBoxButtons.OK, MessageBoxIcon.Information);
             return false;
         }
        }

        public bool validarArquivos()
        {
            if (String.IsNullOrEmpty(txtOrigem.Text))
            {
                return false;
            }
            if (String.IsNullOrEmpty(txtDestino.Text))
            {
                return false;
            }
            return true;
        }

        private void btnDestino_Click(object sender, EventArgs e)
        {
            OpenFileDialog dialogo = new OpenFileDialog(); 
            
            dialogo.InitialDirectory =  Path.GetDirectoryName(@txtDestino.Text);
            dialogo.ShowDialog();
        }

        private void btnSair_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void btnOrigem_Click(object sender, EventArgs e)
        {
            OpenFileDialog dialogo = new OpenFileDialog();
            dialogo.FilterIndex = 1;
            if (dialogo.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                   txtOrigem.Text = dialogo.FileName;
            }
        }
    }
}
